==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/systemtags/l10n/tr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "%1$s sistem etiketi sistem tarafından eklendi",
    "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
    "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
    "%1$s added system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} added system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "System tag %1$s removed by the system" : "%1$s sistem etiketi sistem tarafından kaldırıldı",
    "Removed system tag {systemtag}" : "{systemtag} sistem etiketi silindi",
    "Removed system tag %1$s" : "%1$s sistem etiketi silindi",
    "%1$s removed system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} removed system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You created system tag %1$s" : "%1$s sistem etiketini eklediniz",
    "You created system tag {systemtag}" : "{systemtag} sistem etiketini eklediniz",
    "%1$s created system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} created system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "You deleted system tag %1$s" : "%1$s sistem etiketini sildiniz",
    "You deleted system tag {systemtag}" : "{systemtag} sistem etiketini sildiniz",
    "%1$s deleted system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} deleted system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You updated system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s olarak güncellediniz",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistem etiketini {newsystemtag} olarak güncellediniz",
    "%1$s updated system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s olarak güncelledi",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}, {oldsystemtag} sistem etiketini {newsystemtag} olarak güncelledi",
    "System tag %2$s was added to %1$s by the system" : "%2$s sistem etiketi %1$s dosyasına sistem tarafından eklendi",
    "System tag {systemtag} was added to {file} by the system" : "{systemtag} sistem etiketi {file} dosyasına sistem tarafından eklendi",
    "You added system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s dosyasına eklediniz",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistem etiketini {file} dosyasına eklediniz",
    "%1$s added system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasına ekledi",
    "{actor} added system tag {systemtag} to {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasına eklediniz",
    "System tag %2$s was removed from %1$s by the system" : "%2$s sistem etiketi %1$s dosyasından sistem tarafından kaldırıldı",
    "System tag {systemtag} was removed from {file} by the system" : "{systemtag} sistem etiketi {file} dosyasından sistem tarafından kaldırıldı",
    "You removed system tag %2$s from %1$s" : "%2$s sistem etiketini %1$s dosyasından sildiniz",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
    "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
    "%s (restricted)" : "%s (kısıtlanmış)",
    "%s (invisible)" : "%s (gizli)",
    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildiğinde",
    "Tags" : "Etiketler",
    "All tagged %s …" : "Tüm %s etiketliler…",
    "tagged %s" : "%s etiketli",
    "Collaborative tags" : "İş birlikli etiketler",
    "Collaborative tagging functionality which shares tags among users." : "Etiketlerin kullanıcılar arasında paylaşılabilmesini sağlayan iş birlikli etiketleme özelliği.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İş birlikli etiketler özelliği etiketlerin kullanıcılar arasında paylaşılabilmesini sağlar. Takımlar için harikadır. \n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın devre dışı bırakılması önerilir).",
    "Create or edit tags" : "Etiket ekle ya da düzenle",
    "Search for a tag to edit" : "Düzenlemek için bir etiket ara",
    "Collaborative tags …" : "İş birlikli etiketler…",
    "No tags to select" : "Seçilebilecek bir etiket yok",
    "Tag name" : "Etiket adı",
    "Tag level" : "Etiket düzeyi",
    "Create" : "Ekle",
    "Update" : "Güncelle",
    "Delete" : "Sil",
    "Reset" : "Sıfırla",
    "Loading …" : "Yükleniyor…",
    "Public" : "Herkese açık",
    "Restricted" : "Kısıtlanmış",
    "Invisible" : "Gizli",
    "Created tag" : "Etiket oluşturuldu",
    "Failed to create tag" : "Etiket eklenemedi",
    "Updated tag" : "Etiket güncellendi",
    "Failed to update tag" : "Etiket güncellenemedi",
    "Deleted tag" : "Etiket silindi",
    "Failed to delete tag" : "Etiket silinemedi",
    "Loading collaborative tags …" : "İş birlikli etiketler yükleniyor…",
    "Search or create collaborative tags" : "İş birlikli etiket ara ya da ekle",
    "No tags to select, type to create a new tag" : "Seçilebilecek herhangi bir etiket yok. Yazarak yeni bir etiket ekleyin",
    "Failed to load tags" : "Etiketler yüklenemedi",
    "Failed to load selected tags" : "Seçilmiş etiketler yüklenemedi",
    "Failed to select tag" : "Seçilmiş etiket yüklenemedi",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İş birlikli etiketleri tüm kullanıcılar kullanabilir. Kısıtlanmış etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
    "This file has the tag {tag}" : "Dosya {tag} olarak etiketlenmiş",
    "This file has the tags {firstTags} and {lastTag}" : "Dosya {firstTags} ve {lastTag} olarak etiketlenmiş",
    "List of tags and their associated files and folders." : "Etiketlerin ve ilişkili dosya ve klasörlerin listesi.",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Tags you have created will show up here." : "Oluşturduğunuz etiketler burada görüntülenir.",
    "Failed to load last used tags" : "Son kullanılan etiketler yüklenemedi",
    "Missing \"Content-Location\" header" : "\"Content-Location\" üst bilgisi eksik",
    "Failed to load tags for file" : "Dosyanın etiketleri yüklenemedi",
    "Failed to set tag for file" : "Dosyanın etiketi ayarlanamadı",
    "Failed to delete tag for file" : "Dosyanın etiketi silinemedi",
    "Tag name is empty" : "Etiket adı boş",
    "Select tag …" : "Etiket seçin …",
    "Tagged files" : "Etiketli dosyalar",
    "Select tags to filter by" : "Süzülecek etiketleri seçin",
    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
    "Create a new tag" : "Etiket ekle",
    "Name" : "Ad",
    "No files in here" : "Burada henüz bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme"
},
"nplurals=2; plural=(n > 1);");

==> php82-nextcloud-30.0.11.tgz: share/nextcloud/apps/systemtags/l10n/tr.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "%1$s sistem etiketi sistem tarafından eklendi",
    "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
    "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
    "%1$s added system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} added system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "System tag %1$s removed by the system" : "%1$s sistem etiketi sistem tarafından kaldırıldı",
    "Removed system tag {systemtag}" : "{systemtag} sistem etiketi silindi",
    "Removed system tag %1$s" : "%1$s sistem etiketi silindi",
    "%1$s removed system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} removed system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You created system tag %1$s" : "%1$s sistem etiketini eklediniz",
    "You created system tag {systemtag}" : "{systemtag} sistem etiketini eklediniz",
    "%1$s created system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} created system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "You deleted system tag %1$s" : "%1$s sistem etiketini sildiniz",
    "You deleted system tag {systemtag}" : "{systemtag} sistem etiketini sildiniz",
    "%1$s deleted system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} deleted system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You updated system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s olarak güncellediniz",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistem etiketini {newsystemtag} olarak güncellediniz",
    "%1$s updated system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s olarak güncelledi",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}, {oldsystemtag} sistem etiketini {newsystemtag} olarak güncelledi",
    "System tag %2$s was added to %1$s by the system" : "%2$s sistem etiketi %1$s dosyasına sistem tarafından eklendi",
    "System tag {systemtag} was added to {file} by the system" : "{systemtag} sistem etiketi {file} dosyasına sistem tarafından eklendi",
    "You added system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s dosyasına eklediniz",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistem etiketini {file} dosyasına eklediniz",
    "%1$s added system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasına ekledi",
    "{actor} added system tag {systemtag} to {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasına eklediniz",
    "System tag %2$s was removed from %1$s by the system" : "%2$s sistem etiketi %1$s dosyasından sistem tarafından kaldırıldı",
    "System tag {systemtag} was removed from {file} by the system" : "{systemtag} sistem etiketi {file} dosyasından sistem tarafından kaldırıldı",
    "You removed system tag %2$s from %1$s" : "%2$s sistem etiketini %1$s dosyasından sildiniz",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
    "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
    "%s (restricted)" : "%s (kısıtlanmış)",
    "%s (invisible)" : "%s (gizli)",
    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildiğinde",
    "Files" : "Dosyalar",
    "Tags" : "Etiketler",
    "All tagged %s …" : "Tüm %s etiketliler…",
    "tagged %s" : "%s etiketli",
    "Collaborative tags" : "İş birlikli etiketler",
    "Collaborative tagging functionality which shares tags among people." : "Etiketlerin kişiler arasında paylaşılabilmesini sağlayan iş birlikli etiketleme özelliği.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İş birlikli etiketler özelliği etiketlerin kişiler arasında paylaşılabilmesini sağlar. Takımlar için harikadır.\n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın kullanımdan kaldırılması önerilir).",
    "Public" : "Herkese açık",
    "Restricted" : "Kısıtlanmış",
    "Invisible" : "Gizli",
    "Created tag" : "Etiket oluşturuldu",
    "Failed to create tag" : "Etiket eklenemedi",
    "Updated tag" : "Etiket güncellendi",
    "Failed to update tag" : "Etiket güncellenemedi",
    "Deleted tag" : "Etiket silindi",
    "Failed to delete tag" : "Etiket silinemedi",
    "Create or edit tags" : "Etiket ekle ya da düzenle",
    "Search for a tag to edit" : "Düzenlemek için bir etiket ara",
    "Collaborative tags …" : "İş birlikli etiketler…",
    "No tags to select" : "Seçilebilecek bir etiket yok",
    "Tag name" : "Etiket adı",
    "Tag level" : "Etiket düzeyi",
    "Create" : "Ekle",
    "Update" : "Güncelle",
    "Delete" : "Sil",
    "Reset" : "Sıfırla",
    "Loading …" : "Yükleniyor…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["Bir dosyada {tag1} eklenecek ve {tag2} kaldırılacak.","{count} dosyada {tag1} eklenecek ve {tag2} kaldırılacak."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["Bir dosyaya {tag} eklenecek.","{count} dosyaya {tag} eklenecek."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["Bir dosyadan {tag} kaldırılacak.","{count} dosyadan {tag} kaldırılacak."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["Bir dosyaya {tags} ve {lastTag} eklenecek.","{count} dosyaya {tags} ve {lastTag} eklenecek."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["Bir dosyadan {tags} ve {lastTag} kaldırılacak.","{count} dosyadan {tags} ve {lastTag} kaldırılacak."],
    "{displayName} (hidden)" : "{displayName} (gizli)",
    "{displayName} (restricted)" : "{displayName} (kısıtlanmış)",
    "Only admins can create new tags" : "Yalnızca yöneticiler yeni etiketler ekleyebilir",
    "Failed to apply tags changes" : "Etiket değişiklikleri uygulanamadı",
    "File tags modification canceled" : "Dosya etiket değişikliği iptal edildi",
    "Manage tags" : "Etiket yönetimi",
    "Applying tags changes…" : "Etiket değişikllikleri uygulanıyor…",
    "Search or create tag" : "Etiket arayın ya da oluşturun",
    "Search tag" : "Etiket arama",
    "Change tag color" : "Etiket rengini değiştir",
    "Create new tag" : "Etiket ekle",
    "Select or create tags to apply to all selected files" : "Tüm seçilmiş dosyalara uygulanacak etiketleri seçin ya da oluşturun",
    "Select tags to apply to all selected files" : "Tüm seçilmiş dosyalara uygulanacak etiketleri seçin",
    "Cancel" : "İptal",
    "Apply changes" : "Değişiklikleri uygula",
    "Failed to load tags" : "Etiketler yüklenemedi",
    "Failed to load selected tags" : "Seçilmiş etiketler yüklenemedi",
    "Failed to select tag" : "Seçilmiş etiket yüklenemedi",
    "System admin disabled tag creation. You can only use existing ones." : "Sistem yöneticisi etiket oluşturma iznini kaldırmış. Yalnızca var olan etiketleri kullanabilirsiniz.",
    "Loading collaborative tags …" : "İş birlikli etiketler yükleniyor…",
    "Search or create collaborative tags" : "İş birlikli etiket ara ya da ekle",
    "No tags to select, type to create a new tag" : "Seçilebilecek herhangi bir etiket yok. Yazarak yeni bir etiket ekleyin",
    "Unable to update setting" : "Ayar güncellenemedi",
    "System tag creation is now restricted to administrators" : "Sistem etiketlerini yalnızca yöneticiler oluşturabilir",
    "System tag creation is now allowed for everybody" : "Sistem etiketlerini tüm kullanıcılar oluşturabilir",
    "System tag management" : "Sistem etiket yönetimi",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Bu seçenek kullanıma alındığında, etiketleri yalnızca yöneticiler ekleyebilir ve düzenleyebilir. Kullanıcı hesapları yalnızca dosyalara atayabilir ve kaldırabilir.",
    "Restrict tag creation and editing to administrators" : "Etiket ekleme ve düzenleme yöneticilerle sınırlansın",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İş birlikli etiketleri tüm kullanıcılar kullanabilir. Kısıtlanmış etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
    "Assigned collaborative tags" : "Atanmış iş birlikli etiketler",
    "Open in Files" : "Dosyalar uygulamasında aç",
    "List of tags and their associated files and folders." : "Etiketlerin ve ilişkili dosya ve klasörlerin listesi.",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Tags you have created will show up here." : "Oluşturduğunuz etiketler burada görüntülenir.",
    "Failed to load tag" : "Etiket yüklenemedi",
    "Failed to load last used tags" : "Son kullanılan etiketler yüklenemedi",
    "Missing \"Content-Location\" header" : "\"Content-Location\" üst bilgisi eksik",
    "A tag with the same name already exists" : "Aynı adlı bir etiket zaten var",
    "Failed to load tags for file" : "Dosyanın etiketleri yüklenemedi",
    "Failed to set tag for file" : "Dosyanın etiketi ayarlanamadı",
    "Failed to delete tag for file" : "Dosyanın etiketi silinemedi",
    "This file has the tag {tag}" : "Dosya {tag} olarak etiketlenmiş",
    "This file has the tags {firstTags} and {lastTag}" : "Dosya {firstTags} ve {lastTag} olarak etiketlenmiş"
},
"nplurals=2; plural=(n > 1);");
